@@ -5,9 +5,13 @@ from typing import List, Set, Tuple
 
 from boto3.resources.base import ServiceResource as Boto3ServiceResource
 
+from mypy_boto3_builder.enums.service_module_name import ServiceModuleName
 from mypy_boto3_builder.import_helpers.import_string import ImportString
+from mypy_boto3_builder.import_helpers.internal_import_record import InternalImportRecord
 from mypy_boto3_builder.service_name import ServiceName
+from mypy_boto3_builder.structures.attribute import Attribute
 from mypy_boto3_builder.structures.class_record import ClassRecord
+from mypy_boto3_builder.structures.client import Client
 from mypy_boto3_builder.structures.collection import Collection
 from mypy_boto3_builder.structures.resource import Resource
 from mypy_boto3_builder.type_annotations.external_import import ExternalImport
@@ -28,6 +32,7 @@ class ServiceResource(ClassRecord):
         service_name: ServiceName,
         boto3_service_resource: Boto3ServiceResource,
     ):
+        self.resource_meta_class = self._get_resource_meta_class(service_name)
         super().__init__(
             name=name,
             bases=[
@@ -37,6 +42,16 @@ class ServiceResource(ClassRecord):
                     alias="Boto3ServiceResource",
                 )
             ],
+            attributes=[
+                Attribute(
+                    "meta",
+                    InternalImport(
+                        self.resource_meta_class.name,
+                        service_name,
+                        ServiceModuleName.service_resource,
+                    ),
+                )
+            ],
         )
         self.service_name = service_name
         self.boto3_service_resource = boto3_service_resource
@@ -46,6 +61,35 @@ class ServiceResource(ClassRecord):
     def __hash__(self) -> int:
         return hash(self.service_name)
 
+    @staticmethod
+    def get_class_name(service_name: ServiceName) -> str:
+        """
+        Get class name for ServiceName.
+        """
+        return f"{service_name.class_name}ServiceResource"
+
+    def _get_resource_meta_class(self, service_name: ServiceName) -> ClassRecord:
+        return ClassRecord(
+            name=f"{service_name.class_name}ResourceMeta",
+            bases=[
+                ExternalImport(
+                    source=ImportString("boto3", "resources", "base"),
+                    name="ResourceMeta",
+                )
+            ],
+            attributes=[Attribute("client", self._get_client_import(service_name))],
+        )
+
+    def _get_client_import(self, service_name: ServiceName) -> ExternalImport:
+        client_import = ExternalImport(
+            source=ImportString(service_name.module_name, ServiceModuleName.client.value),
+            name=Client.get_class_name(service_name),
+        )
+        client_import.import_record = InternalImportRecord(
+            ServiceModuleName.client, client_import.name
+        )
+        return client_import
+
     @property
     def boto3_doc_link(self) -> str:
         """
@@ -70,6 +114,7 @@ class ServiceResource(ClassRecord):
         Extract type annotations for collections and sub-resources.
         """
         types = super().get_types()
+        types.update(self.resource_meta_class.get_types())
         for collection in self.collections:
             types.update(collection.get_types())
         for sub_resource in self.sub_resources:
