@@ -22,8 +22,8 @@ METHOD_MAP: ServiceTypeMap = {
         "Instance": {
             "delete_tags": [
                 Argument("self", None),
-                Argument("Tags", TypeSubscript(Type.Sequence, [ec2_tag_type]), Type.none),
-                Argument("DryRun", Type.bool, Type.none),
+                Argument("Tags", TypeSubscript(Type.Sequence, [ec2_tag_type]), Type.Ellipsis),
+                Argument("DryRun", Type.bool, Type.Ellipsis),
             ]
         },
     },
