@@ -1,13 +1,14 @@
 """
 Service package writer.
 """
-import shutil
 from pathlib import Path
 from typing import List, Tuple
 
 from mypy_boto3_builder.enums.service_module_name import ServiceModuleName
+from mypy_boto3_builder.logger import get_logger
 from mypy_boto3_builder.structures.service_package import ServicePackage
 from mypy_boto3_builder.utils.markdown import fix_pypi_headers
+from mypy_boto3_builder.utils.nice_path import NicePath
 from mypy_boto3_builder.writers.utils import (
     blackify,
     format_md,
@@ -17,9 +18,7 @@ from mypy_boto3_builder.writers.utils import (
 )
 
 
-def write_service_package(
-    package: ServicePackage, output_path: Path, generate_setup: bool
-) -> List[Path]:
+def write_service_package(package: ServicePackage, output_path: Path, generate_setup: bool) -> None:
     """
     Create stubs files for service.
 
@@ -28,18 +27,14 @@ def write_service_package(
         output_path -- Path to output folder.
         generate_setup -- Generate ready-to-install or to-use package.
     """
+    logger = get_logger()
     setup_path = output_path / f"{package.service_name.module_name}_package"
-    if not generate_setup:
-        setup_path = output_path
+    if generate_setup:
+        package_path = setup_path / package.name
+    else:
+        package_path = output_path / package.name
 
-    modified_paths: List[Path] = []
-    package_path = setup_path / package.name
-
-    if setup_path.exists():
-        shutil.rmtree(setup_path)
-
-    setup_path.mkdir(exist_ok=True)
-    package_path.mkdir(exist_ok=True)
+    package_path.mkdir(exist_ok=True, parents=True)
 
     templates_path = Path("service")
     module_templates_path = templates_path / "service"
@@ -149,13 +144,16 @@ def write_service_package(
             content = format_md(content)
 
         if not file_path.exists() or file_path.read_text() != content:
-            modified_paths.append(file_path)
             file_path.write_text(content)
+            logger.debug(f"Updated {NicePath(file_path)}")
 
-    return modified_paths
+    valid_paths = dict(file_paths).keys()
+    for unknown_path in NicePath(setup_path if generate_setup else package_path).walk(valid_paths):
+        unknown_path.unlink()
+        logger.debug(f"Deleted {NicePath(unknown_path)}")
 
 
-def write_service_docs(package: ServicePackage, output_path: Path) -> List[Path]:
+def write_service_docs(package: ServicePackage, output_path: Path) -> None:
     """
     Create service docs files.
 
@@ -163,7 +161,7 @@ def write_service_docs(package: ServicePackage, output_path: Path) -> List[Path]
         package -- Service package.
         output_path -- Path to output folder.
     """
-    modified_paths = []
+    logger = get_logger()
     docs_path = output_path / f"{package.service_name.module_name}"
     docs_path.mkdir(exist_ok=True)
     templates_path = Path("service_docs")
@@ -198,7 +196,10 @@ def write_service_docs(package: ServicePackage, output_path: Path) -> List[Path]
         content = insert_md_toc(content)
         content = format_md(content)
         if not file_path.exists() or file_path.read_text() != content:
-            modified_paths.append(file_path)
             file_path.write_text(content)
+            logger.debug(f"Updated {NicePath(file_path)}")
 
-    return modified_paths
+    valid_paths = dict(file_paths).keys()
+    for unknown_path in NicePath(docs_path).walk(valid_paths):
+        unknown_path.unlink()
+        logger.debug(f"Deleted {NicePath(unknown_path)}")
